@@ -19,6 +19,7 @@ import sys
 from string import Formatter
 
 from nuitka.PythonFlavors import getPythonFlavorName
+from nuitka.PythonVersions import isPythonWithGil
 from nuitka.utils.CommandLineOptions import SUPPRESS_HELP, makeOptionsParser
 from nuitka.utils.FileOperations import getFileContentByLine
 from nuitka.utils.Utils import (
@@ -287,8 +288,8 @@ follow_group.add_option(
     default=[],
     help="""\
 Do not follow to that module name even if used, or if a package name, to the
-whole package in any case, overrides all other options. Can be given multiple
-times. Default empty.""",
+whole package in any case, overrides all other options. This can also contain
+patterns, e.g. "*.tests". Can be given multiple times. Default empty.""",
 )
 
 follow_group.add_option(
@@ -454,6 +455,18 @@ data_group.add_option(
 Output the data files found for a given package name. Default not done.""",
 )
 
+data_group.add_option(
+    "--include-raw-dir",
+    action="append",
+    dest="raw_dirs",
+    metavar="DIRECTORY",
+    default=[],
+    help="""\
+Include raw directories completely in the distribution. This is
+recursive. Check '--include-data-dir' to use the sane option.
+Default empty.""",
+)
+
 
 del data_group
 
@@ -577,18 +590,6 @@ Execute inside a debugger, e.g. "gdb" or "lldb" to automatically get a stack tra
 Defaults to off.""",
 )
 
-execute_group.add_option(
-    "--execute-with-pythonpath",
-    action="store_true",
-    dest="keep_pythonpath",
-    default=False,
-    help="""\
-When immediately executing the created binary or module using '--run',
-don't reset 'PYTHONPATH' environment. When all modules are successfully
-included, you ought to not need PYTHONPATH anymore, and definitely not
-for standalone mode.""",
-)
-
 del execute_group
 
 
@@ -738,7 +739,19 @@ Keep deployment mode, but disable selectively parts of it. Errors from
 deployment mode will output these identifiers. Default empty.""",
 )
 
-del deployment_group
+environment_group = parser.add_option_group("Environment control")
+
+environment_group.add_option(
+    "--force-runtime-environment-variable",
+    action="append",
+    dest="forced_runtime_env_variables",
+    metavar="VARIABLE_SPEC",
+    default=[],
+    help="""\
+Force an environment variables to a given value. Default empty.""",
+)
+
+del environment_group
 
 debug_group = parser.add_option_group("Debug features")
 
@@ -752,6 +765,25 @@ Executing all self checks possible to find errors in Nuitka, do not use for
 production. Defaults to off.""",
 )
 
+debug_group.add_option(
+    "--no-debug-immortal-assumptions",
+    action="store_false",
+    dest="debug_immortal",
+    default=None,
+    help="""\
+Disable check normally done with "--debug". With Python3.12+ do not check known
+immortal object assumptions. Some C libraries corrupt them. Defaults to check
+being made if "--debug" is on.""",
+)
+
+debug_group.add_option(
+    "--debug-immortal-assumptions",
+    action="store_true",
+    dest="debug_immortal",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
 debug_group.add_option(
     "--unstripped",
     "--unstriped",
@@ -940,8 +972,9 @@ c_compiler_group.add_option(
     metavar="N",
     default=None,
     help="""\
-Specify the allowed number of parallel C compiler jobs. Defaults to the
-system CPU count.""",
+Specify the allowed number of parallel C compiler jobs. Negative values
+are system CPU minus the given value. Defaults to the full system CPU
+count unless low memory mode is activated, then it defaults to 1.""",
 )
 
 c_compiler_group.add_option(
@@ -1070,7 +1103,7 @@ del caching_group
 pgo_group = parser.add_option_group("PGO compilation choices")
 
 pgo_group.add_option(
-    "--pgo",
+    "--pgo-c",
     action="store_true",
     dest="is_c_pgo",
     default=False,
@@ -1281,29 +1314,6 @@ del tracing_group
 
 os_group = parser.add_option_group("General OS controls")
 
-os_group.add_option(
-    "--disable-console",
-    "--macos-disable-console",
-    "--windows-disable-console",
-    action="store_true",
-    dest="disable_console",
-    default=None,
-    help="""\
-When compiling for Windows or macOS, disable the console window and create a GUI
-application. Defaults to off.""",
-)
-
-os_group.add_option(
-    "--enable-console",
-    action="store_false",
-    dest="disable_console",
-    default=None,
-    help="""\
-When compiling for Windows or macOS, enable the console window and create a console
-application. This disables hints from certain modules, e.g. "PySide" that suggest
-to disable it. Defaults to true.""",
-)
-
 os_group.add_option(
     "--force-stdout-spec",
     "--windows-force-stdout-spec",
@@ -1338,11 +1348,18 @@ del os_group
 windows_group = parser.add_option_group("Windows specific controls")
 
 windows_group.add_option(
-    "--windows-dependency-tool",
+    "--windows-console-mode",
     action="store",
-    dest="dependency_tool",
+    dest="console_mode",
+    choices=("force", "disable", "attach"),
+    metavar="CONSOLE_MODE",
     default=None,
-    help=SUPPRESS_HELP,
+    help="""\
+Select console mode to use. Default mode is 'force' and creates a
+console window unless the program was started from one. With 'disable'
+it doesn't create or use a console at all. With 'attach' an existing
+console will be used for outputs. Default is 'force'.
+""",
 )
 
 windows_group.add_option(
@@ -1396,6 +1413,33 @@ Request Windows User Control, to enforce running from a few folders only, remote
 desktop access. (Windows only). Defaults to off.""",
 )
 
+windows_group.add_option(
+    "--disable-console",
+    "--macos-disable-console",
+    "--windows-disable-console",
+    action="store_true",
+    dest="disable_console",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+windows_group.add_option(
+    "--enable-console",
+    action="store_false",
+    dest="disable_console",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+windows_group.add_option(
+    "--windows-dependency-tool",
+    action="store",
+    dest="dependency_tool",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+
 del windows_group
 
 
@@ -1646,12 +1690,33 @@ plugin_group.add_option(
     dest="plugins_disabled",
     metavar="PLUGIN_NAME",
     default=[],
+    github_action=False,
     help="""\
 Disabled plugins. Must be plug-in names. Use '--plugin-list' to query the
 full list and exit. Most standard plugins are not a good idea to disable.
 Default empty.""",
 )
 
+plugin_group.add_option(
+    "--user-plugin",
+    action="append",
+    dest="user_plugins",
+    metavar="PATH",
+    default=[],
+    help="The file name of user plugin. Can be given multiple times. Default empty.",
+)
+
+plugin_group.add_option(
+    "--plugin-list",
+    action="store_true",
+    dest="plugin_list",
+    default=False,
+    require_compiling=False,
+    github_action=False,
+    help="""\
+Show list of all available plugins and exit. Defaults to off.""",
+)
+
 plugin_group.add_option(
     "--plugin-no-detection",
     action="store_false",
@@ -1665,25 +1730,6 @@ this detection code is run in vain once you are certain of which plugins to
 use. Defaults to off.""",
 )
 
-plugin_group.add_option(
-    "--plugin-list",
-    action="store_true",
-    dest="plugin_list",
-    default=False,
-    require_compiling=False,
-    help="""\
-Show list of all available plugins and exit. Defaults to off.""",
-)
-
-plugin_group.add_option(
-    "--user-plugin",
-    action="append",
-    dest="user_plugins",
-    metavar="PATH",
-    default=[],
-    help="The file name of user plugin. Can be given multiple times. Default empty.",
-)
-
 plugin_group.add_option(
     "--module-parameter",
     action="append",
@@ -1696,12 +1742,12 @@ to provide extra decisions. Format is currently
 Default empty.""",
 )
 
-
 plugin_group.add_option(
     "--show-source-changes",
     action="append",
     dest="show_source_changes",
     default=[],
+    github_action=False,
     help="""\
 Show source changes to original Python file content before compilation. Mostly
 intended for developing plugins and Nuitka package configuration. Use e.g.
@@ -1712,6 +1758,23 @@ Default empty.""",
 
 del plugin_group
 
+target_group = parser.add_option_group("Cross compilation")
+
+
+target_group.add_option(
+    "--target",
+    action="store",
+    dest="target_desc",
+    metavar="TARGET_DESC",
+    default=None,
+    help="""\
+Cross compilation target. Highly experimental and in development, not
+supposed to work yet. We are working on '--target=wasi' and nothing
+else yet.""",
+)
+
+del target_group
+
 
 def _considerPluginOptions(logger):
     # Cyclic dependency on plugins during parsing of command line.
@@ -1791,6 +1854,7 @@ def _expandProjectArg(arg, filename_arg, for_eval):
         "Version": getNuitkaVersion(),
         "Commercial": wrap(getCommercialVersion()),
         "MAIN_DIRECTORY": wrap(os.path.dirname(filename_arg) or "."),
+        "GIL": isPythonWithGil(),
     }
 
     if isLinux():
